#! /usr/bin/env python3
# -*- coding: utf-8 -*-
#
# Copyright © 2016-2018 Cyril Desjouy <ipselium@free.fr>
#
# This file is part of hwinfo
#
# hwinfo is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# hwinfo is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with hwinfo. If not, see <http://www.gnu.org/licenses/>.
#
#
# Creation Date : jeu. 19 avril 2018 10:40:36 CEST
# Last Modified : jeu. 19 avril 2018 10:48:35 CEST
"""
-----------
DOCSTRING

@author: Cyril Desjouy
"""

from .hwinfo import cpuinfo

__version__ = "0.1.0"
